@@ -1,5 +1,4 @@
 import builtins
-import json
 from os import getenv
 from pathlib import Path
 
@@ -7,9 +6,11 @@ from apigee import utils
 
 APP = "apigeecli"
 CMD = "apigee"
-__version__ = "0.51.1"
-description = "(Unofficial) Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support"
-long_description = """(Unofficial) Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support"""
+__version__ = "0.52.0"
+# description = "(Unofficial) Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support"
+# long_description = """(Unofficial) Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support"""
+description = "An unofficial command-line interface tool for simplifying the use of the Apigee Edge Management API with SSO support (no longer actively maintained)"
+long_description = """apigee-cli is a command-line interface tool designed to simplify the use of the Apigee Edge Management API. It provides a user-friendly experience with features such as SSO support. While Google or Apigee does not officially support the tool, it can be used for general administrative tasks, as a developer package, and to support automation for common development tasks such as CI/CD. With the apigee-cli, you can manage your Apigee Edge credentials using environment variables, config files, or command-line arguments. The tool is highly experimental and is not affiliated with Apigee or Google."""
 
 APIGEE_CLI_DIRECTORY = utils.build_path_str(Path.home(), ".apigee")
 APIGEE_CLI_PLUGINS_DIRECTORY = utils.build_path_str(APIGEE_CLI_DIRECTORY, "plugins")
