@@ -9,15 +9,14 @@ class DeploymentsSerializer:
     ):
         if format == "text":
             return deployment_details.text
-        revisions = []
-        for i in deployment_details.json()["environment"]:
-            revisions.append(
-                {
-                    "name": i["name"],
-                    "revision": [j["name"] for j in i["revision"]],
-                    "state": [j["state"] for j in i["revision"]],
-                }
-            )
+        revisions = [
+            {
+                "name": i["name"],
+                "revision": [j["name"] for j in i["revision"]],
+                "state": [j["state"] for j in i["revision"]],
+            }
+            for i in deployment_details.json()["environment"]
+        ]
         if format == "json":
             return json.dumps(revisions)
         elif format == "table":
