@@ -1,9 +1,6 @@
-import json
-
 import requests
-from requests.exceptions import HTTPError
 
-from apigee import APIGEE_ADMIN_API_URL, auth, console
+from apigee import APIGEE_ADMIN_API_URL, auth
 from apigee.references.serializer import ReferencesSerializer
 
 LIST_ALL_REFERENCES_PATH = (
@@ -56,9 +53,7 @@ class References:
             org_name=self._org_name,
             environment=environment,
         )
-        hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
-        resp = requests.get(uri, headers=hdrs)
-        resp.raise_for_status()
+        resp = self._extracted_from_get_reference_7(uri)
         return ReferencesSerializer().serialize_details(resp, format, prefix=prefix)
 
     def get_reference(self, environment):
@@ -68,10 +63,14 @@ class References:
             environment=environment,
             ref_name=self._ref_name,
         )
+        return self._extracted_from_get_reference_7(uri)
+
+    # TODO Rename this here and in `list_all_references` and `get_reference`
+    def _extracted_from_get_reference_7(self, uri):
         hdrs = auth.set_header(self._auth, headers={"Accept": "application/json"})
-        resp = requests.get(uri, headers=hdrs)
-        resp.raise_for_status()
-        return resp
+        result = requests.get(uri, headers=hdrs)
+        result.raise_for_status()
+        return result
 
     def delete_reference(self):
         pass
