@@ -9,8 +9,8 @@ def silent_callback(ctx, param, value):
 
 def common_silent_options(func):
     func = click.option(
-        '--silent',
-        show_default='toggle silent output',
+        "--silent",
+        show_default="toggle silent output",
         flag_value=True,
         default=False,
         callback=silent_callback,
